@@ -48,6 +48,7 @@ from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.by import By as by
 from selenium.common.exceptions import NoSuchElementException
+from selenium.common.exceptions import TimeoutException
 from selenium.webdriver.firefox.options import Options as FirefoxOptions
 from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.firefox.firefox_binary import FirefoxBinary
@@ -472,9 +473,13 @@ class Firefox:
             self.driver.set_page_load_timeout(300)
             return False
 
-    def getreq(self,url:str,regexpat,timeout=300):
+    def getreq(self,url:str,regexpat,timeout=300,simplify=True):
         """
         regexpat: The pat attribute will be matched within the request URL. pat a regular expression
+        if timeout and/or no match, returns ''
+        else returns 
+            if simply request.url
+            else request (so that can check request.headers, request.response.headers, request.response.status_code etc)
         """
         
         # https://pypi.org/project/selenium-wire/
@@ -499,8 +504,14 @@ class Firefox:
         # Also note that since pat can be a regular expression, 
         # you must escape special characters such as question marks with a slash. 
         # A TimeoutException is raised if no match is found within the timeout period.
-        request = self.driver.wait_for_request(regexpat,timeout)
-        return request.url
+        try:
+            request = self.driver.wait_for_request(regexpat,timeout)
+            if simplify:
+                return request.url
+            else:
+                return request
+        except TimeoutException: 
+            return ''
 
     def refresh(self,seconds=5) -> None:
         self.driver.refresh()
